@@ -11,7 +11,7 @@ use XML::LibXML;
 
 use OTRS::OPM::Maker -command;
 
-our $VERSION = 0.07;
+our $VERSION = '0.12';
 
 sub abstract {
     return "Check if filelist in .sopm includes the files on your disk";
@@ -25,9 +25,10 @@ sub validate_args {
     my ($self, $opt, $args) = @_;
     
     $self->usage_error( 'need path to .sopm' ) if
-        !$args ||
-        !$args->[0] ||
-        !$args->[0] =~ /\.sopm\z/ ||
+        !$args or
+        'ARRAY' ne ref $args or
+        !defined $args->[0] or
+        $args->[0] !~ /\.sopm\z/ or
         !-f $args->[0];
 }
 
@@ -92,7 +93,7 @@ OTRS::OPM::Maker::Command::filetest - check if filelist in .sopm includes the fi
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 AUTHOR
 
